body{foo:0;foo:0;foo:15;foo:-15;foo:15px;foo:-15px}body{foo:.1;foo:-.1;foo:1.1;foo:-1.1;foo:.1;foo:-.1;foo:10.1;foo:-10.1}body{foo:0s;foo:0ms}body{foo:0deg;foo:15deg;foo:-15deg}body{foo:0fr;foo:15fr;foo:-15fr}